@@ -43,6 +43,8 @@ An alternate file may be used by placing its path in the FOG_RC environment vari
   :brightbox_secret:
   :clodo_api_key:
   :clodo_username:
+  :digitalocean_api_key:
+  :digitalocean_client_id:
   :go_grid_api_key:
   :go_grid_shared_secret:
   :google_client_email:
@@ -77,6 +79,11 @@ An alternate file may be used by placing its path in the FOG_RC environment vari
   :rage4_password:
   :riakcs_access_key_id:
   :riakcs_secret_access_key:
+  :softlayer_username:
+  :softlayer_api_key:
+  :softlayer_default_datacenter:
+  :softlayer_cluster:
+  :softlayer_default_domain:
   :stormondemand_username:
   :stormondemand_password:
   :terremark_username:
