@@ -1,4 +1,5 @@
 require "fog/core/deprecated_connection_accessors"
+require "fog/core/cache"
 
 module Fog
   class Model
@@ -20,6 +21,10 @@ module Fog
       merge_attributes(attribs)
     end
 
+    def cache
+      Fog::Cache.new(self)
+    end
+
     def inspect
       Fog::Formatador.format(self)
     end
